prettypretty.color.core
=======================

The modules in ``prettypretty.color`` implement the low-level color API. Most
modules have limited dependencies on the standard library but otherwise stand on
their own. A few modules pull in :mod:`prettypretty.color.spec`, which provides
common type definitions. But :mod:`prettypretty.color.grid` and
:mod:`prettypretty.color.lores` pull in several other color modules.


prettypretty.color.apca
-----------------------

.. automodule:: prettypretty.color.apca
    :members:


prettypretty.color.conversion
-----------------------------

.. automodule:: prettypretty.color.conversion
    :members:


prettypretty.color.difference
-----------------------------

.. automodule:: prettypretty.color.difference
    :members:


prettypretty.color.grid
-----------------------

.. automodule:: prettypretty.color.grid
    :members:


prettypretty.color.lores
------------------------

.. automodule:: prettypretty.color.lores
    :members:


prettypretty.color.serde
------------------------

.. automodule:: prettypretty.color.serde
    :members:


prettypretty.color.space
------------------------

.. automodule:: prettypretty.color.space
    :members:


prettypretty.color.spec
-----------------------

.. automodule:: prettypretty.color.spec
    :members:


prettypretty.color.style
------------------------

.. automodule:: prettypretty.color.style
    :members:


prettypretty.color.theme
------------------------

.. automodule:: prettypretty.color.theme
    :members:
